#
# spec file for package ocaml-cppo
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2015 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ocaml-cppo
Version:        1.6.9
Release:        1.5
%{?ocaml_preserve_bytecode}
Summary:        The C preprocessor written in OCaml
License:        BSD-3-Clause
Group:          Development/Languages/OCaml
URL:            https://opam.ocaml.org/packages/cppo
Source:         %name-%version.tar.xz
BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-rpm-macros >= 20220409
BuildRequires:  ocamlfind(str)
BuildRequires:  ocamlfind(unix)

%description
Cppo is an equivalent of the C preprocessor targeted at the OCaml language and
its variants.

The main purpose of cppo is to provide a lightweight tool for simple macro
substitution (#define) and file inclusion (#include) for the occasional case
when this is useful in OCaml. Processing specific sections of files by calling
external programs is also possible via #ext directives.

The implementation of cppo relies on the standard library of OCaml and on the
standard parsing tools Ocamllex and Ocamlyacc, which contribute to the
robustness of cppo across OCaml versions. 

%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.

%prep
%autosetup -p1

%build
dune_release_pkgs='cppo'
%ocaml_dune_setup
%ocaml_dune_build

%install
%ocaml_dune_install
%ocaml_create_file_list

%check
%ocaml_dune_test

%files -f %name.files
%doc README.md
%_bindir/cppo

%files devel -f %name.files.devel

%changelog
* Mon Jun 13 2022 ohering@suse.de
- Update to version 1.6.9
  See included Changes for details
* Sat Sep 11 2021 ohering@suse.de
- Update to version 1.6.8
  Allow empty patch version
* Thu Jan 21 2021 ohering@suse.de
- Update to version 1.6.7
  See included Changes for details
* Thu Feb 20 2020 ohering@suse.de
- Require current ocaml-rpm-macros
- Remove cppo_ocamlbuild in preparation of ocamlbuild removal
* Fri Nov  1 2019 ohering@suse.de
- Require current dune macros
* Mon Sep 30 2019 ohering@suse.de
- use dune macros from ocaml-rpm-macros
* Mon Sep 23 2019 ohering@suse.de
- Update to 1.6.6
  Fix build
* Tue Feb 19 2019 andy@onthewings.net
- Update install files for ocaml-dune 1.7.1.
* Fri Feb  8 2019 andy@onthewings.net
- Remove ocaml-cppo-1.6.1-install-args.patch and directly call dune
  in the install section.
* Tue Feb  5 2019 andy@onthewings.net
- Update to 1.6.5:
  * Fix tests.
  * Fix 'asr' operator.
- Update build command for latest version of dune.
- Update upstream url (migrated to ocaml-community GitHub account).
* Mon Jun 11 2018 andy@onthewings.net
- Package the .ml and .dune files produced by latest dune.
* Wed Jan 31 2018 antoine.belvire@opensuse.org
- Update to 1.6.1:
  * Emit line directives always containing the file name, as
    mandated starting with ocaml 4.07.
- Update to 1.6.0:
  * BREAKING: cppo and cppo_ocamlbuild are now two distinct opam
    packages.
- Build with dune instead of oasis.
* Tue Jul 25 2017 ohering@suse.de
- Use Group: Development/Languages/OCaml
* Mon Jul 17 2017 ohering@suse.de
- Update Url
* Mon Jul 17 2017 ohering@suse.de
- Wrap specfile conditionals to fix quilt setup
* Mon Jul 17 2017 ohering@suse.de
- Remove autodeps for pre openSUSE 12.1 releases
* Wed May 31 2017 olaf@aepfle.de
- Replace tabs with spaces in generated _oasis file
* Wed May 17 2017 ohering@suse.de
- Update to version 1.5.0
* Mon May 30 2016 ohering@suse.de
- Update to version 1.3.2 (fate#320836)
* Tue Nov 10 2015 ohering@suse.de
- Add hardcoded Provides for pre 12.1 repos
* Mon Nov  9 2015 hpj@urpla.net
- don't use make -jN for build
- require ocaml explicitly for build
* Sat Jan  3 2015 hpj@urpla.net
- initial build: version 1.0.0
